# API Reference

## Classes

```{eval-rst}
.. currentmodule:: pydims

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   CreationFunctions
   DimensionedArray
   DimensionError
```

## Top-level functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

   all
   any
   exp
   concat
   flatten
   fold
   reshape
   stack
```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:
```
